@@ -12,13 +12,6 @@ def flare(action, name, additional_args):
     additional_args = list(additional_args)
 
     if action == "release":
-        if shutil.which("zip") is None:
-            echo_error(f'Please install "zip" to bundle a flare application.')
-            return
-
-
-
-
         additional_args = ["-mzc"]
     elif action == "debug":
         pass
